from typing import Literal

COLORMAPS = Literal[
	'Rainbow RGB',
	'3color-RMB',
	'Red Hot',
	'Yellow',
	'betterRed',
	'blue_orange_icb',
	'mpl-inferno',
	'I Blue',
	'BOP purple',
	'betterOrange',
	'Blue',
	'6_shades',
	'OIMB3',
	'Red/Green',
	'Turbo',
	'mpl-viridis',
	'smart',
	'Thermal',
	'OIMB2',
	'glow',
	'OPF orange',
	'physics',
	'OIMB1',
	'betterCyan',
	'mpl-magma',
	'edges',
	'OPF purple',
	'I Yellow',
	'16_colors',
	'sepia',
	'ICA2',
	'I Forest',
	'ICA3',
	'BOP orange',
	'I Red',
	'3color-CGY',
	'I Green',
	'Fire',
	'Magenta Hot',
	'Orange Hot',
	'unionjack',
	'I Cyan',
	'Cyan Hot',
	'I Magenta',
	'Grays',
	'Cyan',
	'phase',
	'gem',
	'OPF fresh',
	'betterGreen',
	'3color-BMR',
	'betterBlue',
	'Magenta',
	'Red',
	'I Bordeaux',
	'glasbey',
	'glasbey_on_dark',
	'mpl-plasma',
	'3color-YGC',
	'Green',
	'ICA',
	'Yellow Hot',
	'thallium',
	'Spectrum',
	'royal',
	'glasbey_inverted',
	'betterYellow',
	'HiLo',
	'cool',
	'Green Fire Blue',
	'BOP blue',
	'thal',
	'Ice',
	'brgbcmyw',
	'I Purple',
	'3-3-2 RGB',
	'5_ramps',
]
